@@ -51,9 +51,9 @@ from yellowdog_client.object_store.upload import UploadBatchBuilder
 from yd_commands.args import ARGS_PARSER
 from yd_commands.cloudwizard_aws_types import AWSAvailabilityZone
 from yd_commands.compact_json import CompactJSONEncoder
-from yd_commands.id_utils import YDIDType
 from yd_commands.items import Item
 from yd_commands.property_names import NAME, TASK_GROUPS, TASKS
+from yd_commands.rich_console_input_fixed import ConsoleWithInputBackspaceFixed
 from yd_commands.settings import (
     DEFAULT_LOG_WIDTH,
     DEFAULT_THEME,
@@ -61,9 +61,10 @@ from yd_commands.settings import (
     HIGHLIGHTED_STATES,
     JSON_INDENT,
     MAX_LINES_COLOURED_FORMATTING,
-    NAMESPACE_PREFIX_SEPARATOR,
+    NAMESPACE_OBJECT_STORE_PREFIX_SEPARATOR,
     WARNING_STYLE,
 )
+from yd_commands.ydid_utils import YDIDType
 
 try:
     LOG_WIDTH = get_terminal_size().columns
@@ -104,7 +105,9 @@ class PrintTableHighlighter(RegexHighlighter):
 pyexamples_theme = Theme(DEFAULT_THEME)
 
 
-CONSOLE = Console(highlighter=PrintLogHighlighter(), theme=pyexamples_theme)
+CONSOLE = ConsoleWithInputBackspaceFixed(
+    highlighter=PrintLogHighlighter(), theme=pyexamples_theme
+)
 CONSOLE_TABLE = Console(highlighter=PrintTableHighlighter(), theme=pyexamples_theme)
 CONSOLE_ERR = Console(stderr=True, highlighter=PrintLogHighlighter())
 CONSOLE_JSON = Console(highlighter=JSONHighlighter())
@@ -259,11 +262,17 @@ def compute_requirement_table(
         "Compute Requirement Name",
         "Namespace",
         "Tag",
-        "Status (Tgt/Exp)",
+        "Status (Tgt/Exp/Alive)",
         "Compute Requirement ID",
     ]
     table = []
     for index, cr in enumerate(cr_list):
+        alive_count = sum(
+            [
+                source.instanceSummary.aliveCount
+                for source in cr.provisionStrategy.sources
+            ]
+        )
         table.append(
             [
                 index + 1,
@@ -275,7 +284,7 @@ def compute_requirement_table(
                     if cr.nextStatus is None
                     else (f"{cr.status} -> {cr.nextStatus}")
                 )
-                + f" ({cr.targetInstanceCount:,d}/{cr.expectedInstanceCount:,d})",
+                + f" ({cr.targetInstanceCount:,d}/{cr.expectedInstanceCount:,d}/{alive_count:,d})",
                 cr.id,
             ]
         )
@@ -1010,7 +1019,7 @@ def print_batch_upload_files(upload_batch_builder: UploadBatchBuilder):
             [
                 index + 1,
                 file_entry.source_file_path,
-                f"{upload_batch_builder.namespace}{NAMESPACE_PREFIX_SEPARATOR}{file_entry.default_object_name}",
+                f"{upload_batch_builder.namespace}{NAMESPACE_OBJECT_STORE_PREFIX_SEPARATOR}{file_entry.default_object_name}",
             ]
         )
     print(flush=True)
@@ -1039,7 +1048,7 @@ def print_batch_download_files(
     counter = 0
     # Yes, I know I shouldn't be accessing '_source_object_entries'
     for index, object_entry in enumerate(download_batch_builder._source_object_entries):
-        object_source = f"{object_entry.namespace}{NAMESPACE_PREFIX_SEPARATOR}{object_entry.object_name}"
+        object_source = f"{object_entry.namespace}{NAMESPACE_OBJECT_STORE_PREFIX_SEPARATOR}{object_entry.object_name}"
         object_target = (
             f"{object_entry.object_name.replace('/', directory_separator)}"
             if flatten_downloads is False
@@ -1180,7 +1189,7 @@ def print_event(event: str, id_type: YDIDType):
     indent = "\n" + (" " * PREFIX_LEN) + "--> "
     indent_2 = "\n" + (" " * (PREFIX_LEN + 4))
 
-    if id_type == YDIDType.WORK_REQ:
+    if id_type == YDIDType.WORK_REQUIREMENT:
         msg = f"{id_type.value} '{event_data['name']}' is {event_data['status']}"
         for task_group in event_data["taskGroups"]:
             status = task_group["status"]
@@ -1216,12 +1225,19 @@ def print_event(event: str, id_type: YDIDType):
         if len(workers_msg) > 0:
             msg += f"{indent}Worker(s):      " + workers_msg
 
-    elif id_type == YDIDType.COMPUTE_REQ:
+    elif id_type == YDIDType.COMPUTE_REQUIREMENT:
         msg = f"{id_type.value} '{event_data['name']}' is {event_data['status']}"
+        alive_count = sum(
+            [
+                int(source["instanceSummary"]["aliveCount"])
+                for source in event_data["provisionStrategy"]["sources"]
+            ]
+        )
         msg += (
             f"{indent}Instance(s): "
             f"{event_data['targetInstanceCount']:,d} TARGET,"
-            f" {event_data['expectedInstanceCount']:,d} EXPECTED"
+            f" {event_data['expectedInstanceCount']:,d} EXPECTED,"
+            f" {alive_count:,d} ALIVE"
         )
         for source in event_data["provisionStrategy"]["sources"]:
             source_msg = status_counts_msg(
